diff --git a/src/endWeek/player/prPregnancy.js b/src/endWeek/player/prPregnancy.js
index d64b59e3fccabaaeb7f1e69995c2805c263dbdf7..d5978f940e6e4bff66380c891d0f3ea7e6901bfe 100644
--- a/src/endWeek/player/prPregnancy.js
+++ b/src/endWeek/player/prPregnancy.js
@@ -471,10 +471,10 @@ App.EndWeek.Player.pregnancy = function(PC = V.PC) {
 	function impregnation() {
 		if (PC.vagina === 0 || (PC.anus === 0 && PC.mpreg > 0)) {
 			// You aren't putting out.
-			if (isVirile(PC) && PC.geneMods.aggressiveSperm === 1 && canFemImpreg(PC, PC)) {
+			if (PC.geneMods.aggressiveSperm === 1) {
 				// But ejaculating with the sperm mod can result in splashback. More sex, more chances.
 				if (random(1, 100) > (99 - (PC.energy / 2))) {
-					knockMeUp(PC, 0, 2, -1); // 0% chance is correct. Gene mod adds 75% in knockMeUp().
+					tryKnockMeUp(PC, 0, 2, PC); // 0% chance is correct. Gene mod adds 75% in tryKnockMeUp().
 				}
 			}
 		} else if (random(1, 100) > (70 - (V.reproductionFormula * 10))) {
@@ -529,15 +529,15 @@ App.EndWeek.Player.pregnancy = function(PC = V.PC) {
 		}
 		if (canGetPregnant(PC) && !onBedRest(PC, true) && !isPCCareerInCategory("servant")) {
 			// Sperm mod leavings around the penthouse. Gives servants more of a point too.
-			let slobs = V.slaves.filter(s => canFemImpreg(PC, s) && isSlaveAvailable(s) && s.geneMods.aggressiveSperm === 1 && (s.fetish === "mindbroken" || s.energy > 95 || (s.devotion < -20 && s.trust > 20) || (s.intelligence + s.intelligenceImplant < -10)));
+			let slobs = V.slaves.filter(s => isSlaveAvailable(s) && s.geneMods.aggressiveSperm === 1 && (s.fetish === "mindbroken" || s.energy > 95 || (s.devotion < -20 && s.trust > 20) || (s.intelligence + s.intelligenceImplant < -10)));
 			if (slobs.length > (totalServantCapacity() / 5)) {
-				knockMeUp(PC, -50, 2, slobs.random());
+				tryKnockMeUp(PC, -50, 2, slobs.random());
 			}
 		}
 	}
 
 	function autoImpregnation() {
-		knockMeUp(PC, 100, 2, PC.ID);
+		tryKnockMeUp(PC, 100, 2, PC);
 		if (PC.geneticQuirks.superfetation === 2 && PC.pregKnown === 1) {
 			if (V.geneticMappingUpgrade === 0 && PC.counter.birthsTotal === 0) {
 				r.push(`You are wracked with frequent spontaneous orgasms from your asexual reproduction modifications despite already being pregnant.`);